# python3 -m pip install botrun-pdf-to-text
```
from botrun_pdf_text import botrun_pdf_to_text_folder,botrun_pdf_to_text_files,botrun_pdf_to_text_single_file
botrun_pdf_to_text_folder("./users/cbh_cameo_tw/data/upload_files")
botrun_pdf_to_text_files(["./users/cbh_cameo_tw/data/upload_files/222715345.pdf"])
botrun_pdf_to_text_single_file("./users/cbh_cameo_tw/data/upload_files/222715345.pdf")
```